public inbox for linux-nfs@vger.kernel.org
 help / color / mirror / Atom feed
From: Chuck Lever <chuck.lever@oracle.com>
To: steved@redhat.com
Cc: linux-nfs@vger.kernel.org
Subject: [PATCH 12/14] text-based mount options: rename functions in stropts.c
Date: Wed, 09 Jul 2008 20:38:11 -0400	[thread overview]
Message-ID: <20080710003810.6137.99053.stgit@tarkus.1015granger.net> (raw)
In-Reply-To: <20080710001725.6137.83845.stgit-lQeC5l55kZ7wdl/1UfZZQIVfYA8g3rJ/@public.gmane.org>

Clean up: rename a couple of functions in utils/mount/stropts.c to match
the naming convention of the others.

Signed-off-by: Chuck Lever <chuck.lever@oracle.com>
---

 utils/mount/stropts.c |   18 +++++++++---------
 1 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/utils/mount/stropts.c b/utils/mount/stropts.c
index a51cf0b..b54df40 100644
--- a/utils/mount/stropts.c
+++ b/utils/mount/stropts.c
@@ -230,7 +230,7 @@ static int nfs_fix_mounthost_option(const sa_family_t family,
  * Returns zero if the "lock" option is in effect, but statd
  * can't be started.  Otherwise, returns 1.
  */
-static int verify_lock_option(struct mount_options *options)
+static int nfs_verify_lock_option(struct mount_options *options)
 {
 	if (po_rightmost(options, "nolock", "lock") == PO_KEY1_RIGHTMOST)
 		return 1;
@@ -279,7 +279,7 @@ static int nfs_validate_options(struct nfsmount_info *mi)
 	} else {
 		if (!nfs_fix_mounthost_option(mi->family, mi->options))
 			return 0;
-		if (!mi->fake && !verify_lock_option(mi->options))
+		if (!mi->fake && !nfs_verify_lock_option(mi->options))
 			return 0;
 	}
 
@@ -297,7 +297,7 @@ static int nfs_validate_options(struct nfsmount_info *mi)
  * passed-in error is permanent, thus the mount system call
  * should not be retried.
  */
-static int is_permanent_error(int error)
+static int nfs_is_permanent_error(int error)
 {
 	switch (error) {
 	case ESTALE:
@@ -316,13 +316,13 @@ static int is_permanent_error(int error)
  *
  * To handle version and transport protocol fallback properly, we
  * need to parse some of the mount options in order to set up a
  * portmap probe.  Mount options that rewrite_mount_options()
  * doesn't recognize are left alone.
  *
  * Returns a new group of mount options if successful; otherwise
  * NULL is returned if some failure occurred.
  */
-static struct mount_options *rewrite_mount_options(char *str)
+static struct mount_options *nfs_rewrite_mount_options(char *str)
 {
 	struct mount_options *options;
 	char *option, new_option[64];
@@ -475,7 +475,7 @@ static int nfs_retry_nfs23mount(struct nfsmount_info *mi)
 	char *retry_str = NULL;
 	char **extra_opts = mi->extra_opts;
 
-	retry_options = rewrite_mount_options(*extra_opts);
+	retry_options = nfs_rewrite_mount_options(*extra_opts);
 	if (!retry_options)
 		return 0;
 
@@ -604,7 +604,7 @@ static int nfsmount_fg(struct nfsmount_info *mi)
 		if (nfs_try_mount(mi))
 			return EX_SUCCESS;
 
-		if (is_permanent_error(errno))
+		if (nfs_is_permanent_error(errno))
 			break;
 
 		if (time(NULL) > timeout) {
@@ -637,7 +637,7 @@ static int nfsmount_parent(struct nfsmount_info *mi)
 	if (nfs_try_mount(mi))
 		return EX_SUCCESS;
 
-	if (is_permanent_error(errno)) {
+	if (nfs_is_permanent_error(errno)) {
 		mount_error(mi->spec, mi->node, errno);
 		return EX_FAIL;
 	}
@@ -672,7 +672,7 @@ static int nfsmount_child(struct nfsmount_info *mi)
 		if (nfs_try_mount(mi))
 			return EX_SUCCESS;
 
-		if (is_permanent_error(errno))
+		if (nfs_is_permanent_error(errno))
 			break;
 
 		if (time(NULL) > timeout)
@@ -316,13 +316,13 @@ static int is_permanent_error(int error)
  * To handle version and transport protocol fallback properly, we
  * need to parse some of the mount options in order to set up a
- * portmap probe.  Mount options that rewrite_mount_options()
+ * portmap probe.  Mount options that nfs_rewrite_mount_options()
  * doesn't recognize are left alone.
  *


  parent reply	other threads:[~2008-07-10  4:08 UTC|newest]

Thread overview: 22+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2008-07-10  0:37 [PATCH 00/14] Support for mounting NFSv4 servers over IPv6 Chuck Lever
     [not found] ` <20080710001725.6137.83845.stgit-lQeC5l55kZ7wdl/1UfZZQIVfYA8g3rJ/@public.gmane.org>
2008-07-10  0:37   ` [PATCH 01/14] nfs-utils: Introduce new ./configure option: "--enable-ipv6" Chuck Lever
2008-07-10  0:37   ` [PATCH 02/14] text-based mount command: Add headers needed for IPv6 support Chuck Lever
2008-07-10  0:37   ` [PATCH 03/14] mount command: Add functions to manage addresses in string form Chuck Lever
2008-07-10  0:37   ` [PATCH 04/14] text-based mount command: get_client_address support for IPv6 Chuck Lever
     [not found]     ` <20080710003723.6137.51761.stgit-lQeC5l55kZ7wdl/1UfZZQIVfYA8g3rJ/@public.gmane.org>
2008-07-10 19:30       ` J. Bruce Fields
2008-07-10 19:36         ` Chuck Lever
2008-07-10 19:43           ` J. Bruce Fields
2008-07-10 20:35             ` Chuck Lever
     [not found]               ` <76bd70e30807101335y54f8b479v39953a772e08e88c-JsoAwUIsXosN+BqQ9rBEUg@public.gmane.org>
2008-07-11 19:06                 ` J. Bruce Fields
2008-07-11 19:16                   ` Chuck Lever
2008-07-10  0:37   ` [PATCH 05/14] text-based mount command: Add helper to construct network addresses Chuck Lever
2008-07-10  0:37   ` [PATCH 06/14] text-based mount command: "addr=" option support for IPv6 addresses Chuck Lever
2008-07-10  0:37   ` [PATCH 07/14] text-based mount command: "clientaddr=" " Chuck Lever
2008-07-10  0:37   ` [PATCH 08/14] text-based mount command: "mounthost=" " Chuck Lever
2008-07-10  0:37   ` [PATCH 09/14] text-based mount command: Add IPv6 support to set_mandatory_options Chuck Lever
2008-07-10  0:37   ` [PATCH 10/14] text-based mount command: Support raw IPv6 address hostnames Chuck Lever
2008-07-10  0:38   ` [PATCH 11/14] text-based mount command: Remove unused IPv4-only functions Chuck Lever
2008-07-10  0:38   ` Chuck Lever [this message]
2008-07-10  0:38   ` [PATCH 13/14] text-based mount command: remove unnecessary headers from stropts.c Chuck Lever
2008-07-10  0:38   ` [PATCH 14/14] mount command: Remove RPC headers from network.h Chuck Lever
  -- strict thread matches above, loose matches on Subject: below --
2008-07-11 20:34 [PATCH 00/14] Support for mounting NFSv4 servers over IPv6 Chuck Lever
     [not found] ` <20080711203322.478.52095.stgit-lQeC5l55kZ7wdl/1UfZZQIVfYA8g3rJ/@public.gmane.org>
2008-07-11 20:35   ` [PATCH 12/14] text-based mount options: rename functions in stropts.c Chuck Lever

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20080710003810.6137.99053.stgit@tarkus.1015granger.net \
    --to=chuck.lever@oracle.com \
    --cc=linux-nfs@vger.kernel.org \
    --cc=steved@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox